broadcast_mul_into

Function broadcast_mul_into 

pub fn broadcast_mul_into<D, A, B, OpA, OpB>(
    dest: &mut StridedViewMut<'_, D>,
    a: &StridedView<'_, A, OpA>,
    a_axes: &[usize],
    b: &StridedView<'_, B, OpB>,
    b_axes: &[usize],
) -> Result<(), StridedError>
where D: Copy + MaybeSendSync + 'static, A: Copy + Mul<B, Output = D> + MaybeSendSync + 'static, B: Copy + MaybeSendSync + 'static, OpA: ElementOp<A>, OpB: ElementOp<B>,
Broadcasted element-wise multiplication: dest[i] = a[i] * b[i].

a_axes and b_axes map each source axis to an axis of dest. Output axes not referenced by a source operand are treated as stride-0 broadcast axes.