pub struct GatherSpec {
pub offset_dims: Vec<usize>,
pub collapsed_slice_dims: Vec<usize>,
pub start_index_map: Vec<usize>,
pub index_vector_dim: usize,
pub slice_sizes: Vec<usize>,
}Expand description
Gather configuration shared by generic and erased replay.
The fields follow the usual gather vocabulary:
start_index_map[component]names the operand axis controlled by a component in the index vector;collapsed_slice_dimsnames operand axes whose slice size is one and which do not appear as output window axes;offset_dimsnames output axes that represent window offsets;- output axes not in
offset_dimsare batch axes fromstart_indices; index_vector_dim == start_indices_rankrepresents scalar index vectors.
Fields
offset_dims: Vec<usize>collapsed_slice_dims: Vec<usize>start_index_map: Vec<usize>index_vector_dim: usizeslice_sizes: Vec<usize>Trait Implementations
Sourceimpl Clone for GatherSpec
impl Clone for GatherSpec
Sourcefn clone(&self) -> GatherSpec
fn clone(&self) -> GatherSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GatherSpec
impl Debug for GatherSpec
Sourceimpl PartialEq for GatherSpec
impl PartialEq for GatherSpec
Sourcefn eq(&self, other: &GatherSpec) -> bool
fn eq(&self, other: &GatherSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GatherSpec
impl StructuralPartialEq for GatherSpec